@@ -273,53 +273,53 @@ mod tests {
     #[test]
     fn src_input_slice_1() {
         let _ = with_test_sess("foo/d", |mut i| {
-            assert_eq!(i.slice(BytePos(0), BytePos(1)), "f");
-            assert_eq!(i.last_pos, BytePos(1));
-            assert_eq!(i.start_pos, BytePos(1));
+            assert_eq!(i.slice(BytePos(1), BytePos(2)), "f");
+            assert_eq!(i.last_pos, BytePos(2));
+            assert_eq!(i.start_pos, BytePos(2));
             assert_eq!(i.cur(), Some('o'));
 
-            assert_eq!(i.slice(BytePos(1), BytePos(3)), "oo");
-            assert_eq!(i.slice(BytePos(0), BytePos(3)), "foo");
-            assert_eq!(i.last_pos, BytePos(3));
-            assert_eq!(i.start_pos, BytePos(3));
+            assert_eq!(i.slice(BytePos(2), BytePos(4)), "oo");
+            assert_eq!(i.slice(BytePos(1), BytePos(4)), "foo");
+            assert_eq!(i.last_pos, BytePos(4));
+            assert_eq!(i.start_pos, BytePos(4));
             assert_eq!(i.cur(), Some('/'));
         });
     }
 
     #[test]
     fn src_input_reset_to_1() {
-        let _ = with_test_sess("foad", |mut i| {
-            assert_eq!(i.slice(BytePos(0), BytePos(2)), "fo");
-            assert_eq!(i.last_pos, BytePos(2));
-            assert_eq!(i.start_pos, BytePos(2));
+        let _ = with_test_sess("load", |mut i| {
+            assert_eq!(i.slice(BytePos(1), BytePos(3)), "lo");
+            assert_eq!(i.last_pos, BytePos(3));
+            assert_eq!(i.start_pos, BytePos(3));
             assert_eq!(i.cur(), Some('a'));
-            i.reset_to(BytePos(0));
+            i.reset_to(BytePos(1));
 
-            assert_eq!(i.cur(), Some('f'));
-            assert_eq!(i.last_pos, BytePos(0));
-            assert_eq!(i.start_pos, BytePos(0));
+            assert_eq!(i.cur(), Some('l'));
+            assert_eq!(i.last_pos, BytePos(1));
+            assert_eq!(i.start_pos, BytePos(1));
         });
     }
 
     #[test]
     fn src_input_smoke_01() {
         let _ = with_test_sess("foo/d", |mut i| {
-            assert_eq!(i.cur_pos(), BytePos(0));
-            assert_eq!(i.last_pos, BytePos(0));
-            assert_eq!(i.start_pos, BytePos(0));
+            assert_eq!(i.cur_pos(), BytePos(1));
+            assert_eq!(i.last_pos, BytePos(1));
+            assert_eq!(i.start_pos, BytePos(1));
             assert_eq!(i.uncons_while(|c| c.is_alphabetic()), "foo");
 
             // assert_eq!(i.cur_pos(), BytePos(4));
-            assert_eq!(i.last_pos, BytePos(3));
-            assert_eq!(i.start_pos, BytePos(3));
+            assert_eq!(i.last_pos, BytePos(4));
+            assert_eq!(i.start_pos, BytePos(4));
             assert_eq!(i.cur(), Some('/'));
 
             i.bump();
-            assert_eq!(i.last_pos, BytePos(4));
+            assert_eq!(i.last_pos, BytePos(5));
             assert_eq!(i.cur(), Some('d'));
 
             i.bump();
-            assert_eq!(i.last_pos, BytePos(5));
+            assert_eq!(i.last_pos, BytePos(6));
             assert_eq!(i.cur(), None);
         });
     }
@@ -327,13 +327,13 @@ mod tests {
     #[test]
     fn src_input_find_01() {
         let _ = with_test_sess("foo/d", |mut i| {
-            assert_eq!(i.cur_pos(), BytePos(0));
-            assert_eq!(i.last_pos, BytePos(0));
-            assert_eq!(i.start_pos, BytePos(0));
+            assert_eq!(i.cur_pos(), BytePos(1));
+            assert_eq!(i.last_pos, BytePos(1));
+            assert_eq!(i.start_pos, BytePos(1));
 
-            assert_eq!(i.find(|c| c == '/'), Some(BytePos(4)));
-            assert_eq!(i.start_pos, BytePos(4));
-            assert_eq!(i.last_pos, BytePos(4));
+            assert_eq!(i.find(|c| c == '/'), Some(BytePos(5)));
+            assert_eq!(i.start_pos, BytePos(5));
+            assert_eq!(i.last_pos, BytePos(5));
             assert_eq!(i.cur(), Some('d'));
         });
     }
